@@ -1,4 +1,8 @@
 package Getopt::Chain;
+BEGIN {
+  $Getopt::Chain::VERSION = '0.017';
+}
+# ABSTRACT: Command-line processing like svn and git
 
 use warnings;
 use strict;
@@ -6,17 +10,95 @@ use strict;
 use constant DEBUG => $ENV{GOC_TRACE} ? 1 : 0;
 our $DEBUG = DEBUG;
 
+
+use Moose;
+use Getopt::Chain::Carp;
+
+use Getopt::Chain::Builder;
+use Getopt::Chain::Context;
+
+has builder => qw/is ro lazy_build 1/, handles => [qw/ dispatcher /];
+sub _build_builder {
+    require Getopt::Chain::Builder;
+    return Getopt::Chain::Builder->new;
+}
+
+has context_from => qw/is ro isa Str|CodeRef lazy_build 1/;
+sub _build_context_from {
+    return 'Getopt::Chain::Context';
+}
+
+sub process {
+    if (! ref $_[0] && $_[0] && $_[0] eq 'Getopt::Chain') {
+        shift;
+        require Getopt::Chain::v005;
+        carp "Deprecated: Use Getopt::Chain::v005->process( ... ) to avoid this warning (this method will be removed in a future version)";
+        return Getopt::Chain::v005->process( @_ );
+    }
+}
+
+sub run {
+    if (! ref $_[0] ) {
+        croak "Can't call run on the package; use ->new first";
+    }
+    my $self = shift;
+    my $arguments = shift;
+
+    $arguments = [ @ARGV ] unless $arguments;
+
+    my $context = $self->new_context( dispatcher => $self->dispatcher, arguments => $arguments );
+    $context->run;
+    return $context->options;
+}
+
+sub new_context {
+    my $self = shift;
+
+    my $context_from = $self->context_from;
+    if (! ref $context_from) {
+        return $context_from->new( @_ );
+    }
+    else {
+        croak "Don't understand context source \"$context_from\"";
+    }
+}
+
+use MooseX::MakeImmutable;
+MooseX::MakeImmutable->lock_down;
+
+
+1; # End of Getopt::Chain
+
+__END__
+=pod
+
 =head1 NAME
 
 Getopt::Chain - Command-line processing like svn and git
 
 =head1 VERSION
 
-Version 0.016
+version 0.017
 
-=cut
+=head1 DESCRIPTION
 
-our $VERSION = '0.016';
+Getopt::Chain can be used to provide C<svn(1)>- and C<git(1)>-style option and command processing. Any option specification
+covered by L<Getopt::Long> is fair game.
+
+This is a new version of Getopt::Chain that uses L<Path::Dispatcher>
+
+CAVEAT 1: This is pretty beta, so the sugar/interface above WILL be tweaked
+
+CAVEAT 2: Unfortunately, Getopt::Long slurps up the entire arguments array at once. Usually, this isn't a problem (as Getopt::Chain uses 
+pass_through). However, if a subcommand has an option with the same name or alias as an option for a parent, then that option won't be available
+for the subcommand. For example:
+
+    ./script --verbose --revision 36 edit --revision 48 --file xyzzy.c
+    # Getopt::Chain will not associate the second --revision with "edit"
+
+So, for now, try to use distinct option names/aliases :)
+
+DEBUG: You can get some extra information about what Getopt::Chain is doing by setting the environment variable C<GOC_TRACE> to 1
 
 =head1 SYNPOSIS 
 
@@ -94,87 +176,10 @@ our $VERSION = '0.016';
     My::Command->new->run( [ @arguments ] )
     My::Command->new->run # Just run with @ARGV
 
-=head1 DESCRIPTION
-
-Getopt::Chain can be used to provide C<svn(1)>- and C<git(1)>-style option and command processing. Any option specification
-covered by L<Getopt::Long> is fair game.
-
-This is a new version of Getopt::Chain that uses L<Path::Dispatcher>
-
-CAVEAT 1: This is pretty beta, so the sugar/interface above WILL be tweaked
-
-CAVEAT 2: Unfortunately, Getopt::Long slurps up the entire arguments array at once. Usually, this isn't a problem (as Getopt::Chain uses 
-pass_through). However, if a subcommand has an option with the same name or alias as an option for a parent, then that option won't be available
-for the subcommand. For example:
-
-    ./script --verbose --revision 36 edit --revision 48 --file xyzzy.c
-    # Getopt::Chain will not associate the second --revision with "edit"
-
-So, for now, try to use distinct option names/aliases :)
-
-DEBUG: You can get some extra information about what Getopt::Chain is doing by setting the environment variable C<GOC_TRACE> to 1
-
 =head1 LEGACY
 
 The old-style, non L<Path::Dispatcher> version is still available at L<Getopt::Chain::v005>
 
-=cut
-
-use Moose;
-use Getopt::Chain::Carp;
-
-use Getopt::Chain::Builder;
-use Getopt::Chain::Context;
-
-has builder => qw/is ro lazy_build 1/, handles => [qw/ dispatcher /];
-sub _build_builder {
-    require Getopt::Chain::Builder;
-    return Getopt::Chain::Builder->new;
-}
-
-has context_from => qw/is ro isa Str|CodeRef lazy_build 1/;
-sub _build_context_from {
-    return 'Getopt::Chain::Context';
-}
-
-sub process {
-    if (! ref $_[0] && $_[0] && $_[0] eq 'Getopt::Chain') {
-        shift;
-        require Getopt::Chain::v005;
-        carp "Deprecated: Use Getopt::Chain::v005->process( ... ) to avoid this warning (this method will be removed in a future version)";
-        return Getopt::Chain::v005->process( @_ );
-    }
-}
-
-sub run {
-    if (! ref $_[0] ) {
-        croak "Can't call run on the package; use ->new first";
-    }
-    my $self = shift;
-    my $arguments = shift;
-
-    $arguments = [ @ARGV ] unless $arguments;
-
-    my $context = $self->new_context( dispatcher => $self->dispatcher, arguments => $arguments );
-    $context->run;
-    return $context->options;
-}
-
-sub new_context {
-    my $self = shift;
-
-    my $context_from = $self->context_from;
-    if (! ref $context_from) {
-        return $context_from->new( @_ );
-    }
-    else {
-        croak "Don't understand context source \"$context_from\"";
-    }
-}
-
-use MooseX::MakeImmutable;
-MooseX::MakeImmutable->lock_down;
-
 =head1 SEE ALSO
 
 L<Getopt::Long>
@@ -191,63 +196,14 @@ obra for inspiration on the CLI (via Prophet & Sd: L<http://syncwith.us/>)
 
 =head1 AUTHOR
 
-Robert Krimen, C<< <rkrimen at cpan.org> >>
+Robert Krimen <robertkrimen@gmail.com>
 
-=head1 SOURCE
+=head1 COPYRIGHT AND LICENSE
 
-You can contribute or fork this project via GitHub:
-
-L<http://github.com/robertkrimen/Getopt-Chain/tree/master>
-
-    git clone git://github.com/robertkrimen/Getopt-Chain.git Getopt-Chain
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-Getopt-Chain at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Getopt-Chain>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Getopt::Chain
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Getopt-Chain>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Getopt-Chain>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Getopt-Chain>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Getopt-Chain>
-
-=back
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Robert Krimen, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by Robert Krimen.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of Getopt::Chain
